Documentation
¶
Overview ¶
Package mobydriver is a friendly wrapper around Docker's go-plugins-helpers' skd.Handler providing a context.Context-aware ServeUnix method.
Index ¶
Constants ¶
const PluginSocketDir = "/run/docker/plugins"
PluginSocketDir is the path to the directory containing Docker plugin API unix domain sockets.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Handler ¶
Handler wraps Docker's go-plugin-helpers sdk.Handler objects.
func (*Handler) Serve ¶
Serve sets up the handler to serve requests on the passed-in listener, stopping when the passed-in context gets cancelled.
func (*Handler) ServeUnix ¶
ServeUnix creates a handler that then listens for requests on the plugin's API unix domain socket. It also creates the socket file in the Docker plugins directory where the Docker/Moby engine finds it.
It basically mirrors the Docker plugin helper's sdk.Handler.ServeUnix, but giving us a chance to gracefully shut down the plugin's HTTP server.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package ipam provides a context.Context-aware Docker IPAM driver plugin handler.
|
Package ipam provides a context.Context-aware Docker IPAM driver plugin handler. |
|
Package network provides a context.Context-aware Docker network driver plugin handler.
|
Package network provides a context.Context-aware Docker network driver plugin handler. |
|
Package secrets provides a context.Context-aware Docker secrets driver plugin handler.
|
Package secrets provides a context.Context-aware Docker secrets driver plugin handler. |
|
Package volume provides a context.Context-aware Docker volume driver plugin handler.
|
Package volume provides a context.Context-aware Docker volume driver plugin handler. |